@@ -1,4 +1,5 @@
 from twilio.rest.resources import InstanceResource, ListResource
+from six import iteritems
 
 
 class ConnectApp(InstanceResource):
@@ -30,7 +31,7 @@ class AuthorizedConnectApp(ConnectApp):
         """ Translate certain parameters into others"""
         result = {}
 
-        for k, v in entries.iteritems():
+        for k, v in iteritems(entries):
             k = k.replace("connect_app_", "")
             result[k] = v
 
