@@ -102,7 +102,8 @@ class Response(Verb):
         'Reject',
         'Sms',
         'Enqueue',
-        'Leave'
+        'Leave',
+        'Message',
     ]
 
     def __init__(self, **kwargs):
@@ -169,6 +170,11 @@ class Response(Verb):
         :class:`Response` """
         return self.append(Sms(msg, **kwargs))
 
+    def message(self, msg=None, **kwargs):
+        """Return a newly created :class:`Message` verb, nested inside this
+        :class:`Response`"""
+        return self.append(Message(msg, **kwargs))
+
     # All add* methods are deprecated
     def addSay(self, *args, **kwargs):
         return self.say(*args, **kwargs)
@@ -215,7 +221,7 @@ class Say(Verb):
 
     :param loop: specifies how many times you'd like the text repeated.
                  Specifying '0' will cause the the :class:`Say` verb to loop
-                 until the call is hung up.
+                 until the call is hung up. Defaults to 1.
     """
     MAN = 'man'
     WOMAN = 'woman'
@@ -238,7 +244,7 @@ class Play(Verb):
                 correctly.
 
     :param loop: specifies how many times you'd like the text repeated.
-                 Specifying '0' will cause the the :class:`Say` verb to loop
+                 Specifying '0' will cause the the :class:`Play` verb to loop
                  until the call is hung up. Defaults to 1.
     """
     def __init__(self, url, **kwargs):
@@ -355,6 +361,58 @@ class Sms(Verb):
         self.body = msg
 
 
+class Message(Verb):
+    """ Send an MMS Message to a phone number.
+
+    :param to: whom to send message to
+    :param sender: whom to send message from.
+    :param action: url to request after the message is queued
+    :param method: submit to 'action' url using GET or POST
+    :param statusCallback: url to hit when the message is actually sent
+    """
+
+    GET = 'GET'
+    POST = 'POST'
+
+    nestables = ['Media', 'Body']
+
+    def __init__(self, msg=None, **kwargs):
+        super(Message, self).__init__(**kwargs)
+        if msg is not None:
+            self.append(Body(msg))
+
+    def media(self, media_url, **kwargs):
+        return self.append(Media(media_url, **kwargs))
+
+
+class Body(Verb):
+    """ Specify a text body for a Message.
+
+    :param msg: the text to use in the body.
+    """
+
+    GET = 'GET'
+    POST = 'POST'
+
+    def __init__(self, msg, **kwargs):
+        super(Body, self).__init__(**kwargs)
+        self.body = msg
+
+
+class Media(Verb):
+    """Specify media to include in a Message.
+
+    :param url: The URL of the media to include.
+    """
+
+    GET = 'GET'
+    POST = 'POST'
+
+    def __init__(self, url, **kwargs):
+        super(Media, self).__init__(**kwargs)
+        self.body = url
+
+
 class Conference(Verb):
     """Specify conference in a nested Dial element.
 
@@ -445,9 +503,9 @@ class Enqueue(Verb):
                    leaves the queue. When dequeued via a <Dial> verb,
                    this url is executed after the bridged parties disconnect
     :param method: HTTP method for action GET/POST
-    :param wait_url: url to a twiml document that executes
+    :param waitUrl: url to a twiml document that executes
                      while the call is on the queue
-    :param wait_url_method: HTTP method for wait_url GET/POST
+    :param waitUrlMethod: HTTP method for waitUrl GET/POST
     """
     GET = 'GET'
     POST = 'POST'
